=== added file 'ivle/webapp/base/ivle-headings.html'
--- ivle/webapp/base/ivle-headings.html	1970-01-01 00:00:00 +0000
+++ ivle/webapp/base/ivle-headings.html	2009-02-04 03:07:01 +0000
@@ -0,0 +1,76 @@
+<!-- Base Stylesheet used to render all apps -->
+<html xmlns="http://www.w3.org/1999/xhtml"       
+      xmlns:py="http://genshi.edgewall.org/"
+      xmlns:xi="http://www.w3.org/2001/XInclude"
+      py:strip="">
+  <py:match path="head" once="true">
+    <head py:attrs="select('@*')">
+      <!-- Set the appropriate title for the app -->
+      <title py:with="title = list(select('title/text()'))">
+        IVLE<py:if test="title"> - ${title}</py:if>
+      </title>
+      <!-- Set Content Type -->
+      <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
+      <!-- Set global Javascript variables -->
+      <script type="text/javascript">
+        root_dir = "${root_dir}";
+        public_host = "${public_host}";
+        username = "${login}";
+      </script>
+      <link py:if="favicon" rel="shortcut icon" href="${favicon}" />
+      <!-- Global style sheet -->
+      <link rel="stylesheet" type="text/css" href="/media/common/ivle.css" />
+      <!-- Global Javascript-->
+      <script type="text/javascript" src="/media/common/util.js"></script>
+      <script type="text/javascript" src="/media/common/json2.js"></script>
+      <script type="text/javascript" src="/media/common/md5.js"></script>
+      <script type="text/javascript" src="/media/common/tos.js"></script>
+      <!-- App-specific style sheets -->
+      <py:for each="style in app_styles">
+        <link rel="stylesheet" type="text/css" href="${style}" />
+      </py:for>
+      <!-- App-specific Javascript -->
+      <py:for each="script in scripts">
+        <script type="text/javascript" src="${script}"></script>
+      </py:for>
+      <script type="text/javascript">
+        <py:for each="init_script in scripts_init">
+          window.addEventListener("load", ${init_script}, false);
+        </py:for>
+      </script>
+      ${select('*[local-name()!="title"]')}
+    </head>
+  </py:match>    
+  <py:match path="body" once="true">
+    <body>
+      <div id="ivleheader"></div>
+      <div id="ivleheader_text">
+        <h1>IVLE</h1>
+        <h2>Informatics Virtual Learning Environment</h2>
+        <py:choose>
+          <p py:when="publicmode" class="userhello">Running in public mode.</p>
+          <p py:when="logged_in" class="userhello">
+            <span id="usernick">${nick}</span>
+            (<span class="username">${login}</span>) |
+            <a href="/settings">Settings</a> |
+            <a href="/help">Help</a> |
+            <a href="/logout">Sign out</a>
+          </p>
+          <p py:otherwise="">Not logged in.</p>
+        </py:choose>
+      </div>
+      <div id="ivleheader_tabs">
+        <ul id="apptabs">
+          <py:for each="app in apps_in_tabs">
+            <li py:if="app['this_app']" class="thisapp"><py:if test="app['has_icon']"><img src="${app['icon_url']}" alt="" /> </py:if><a href="${app['path']}" title="${app['desc']}">${app['name']}</a></li>
+            <li py:if="not app['this_app']"><py:if test="app['has_icon']"><img src="${app['icon_url']}" alt="" /> </py:if><a href="${app['path']}" title="${app['desc']}">${app['name']}</a></li>
+          </py:for>
+        </ul>
+      </div>
+      <div id="ivlebody">
+      ${select('*')}
+      </div>
+    </body>
+  </py:match>
+  ${app_template}
+</html>

=== modified file 'ivle/webapp/base/views.py'
--- ivle/webapp/base/views.py	2009-02-04 01:43:55 +0000
+++ ivle/webapp/base/views.py	2009-02-04 03:07:01 +0000
@@ -17,7 +17,14 @@
 
 # Author: Matt Giuca, Will Grant
 
+import inspect
+import os.path
+
 import cjson
+import genshi.template
+
+import ivle.conf
+import ivle.util
 
 from ivle.webapp.errors import BadRequest
 
@@ -70,3 +77,62 @@
         if outjson is not None:
             req.write(cjson.encode(outjson))
             req.write("\n")
+            
+class XHTMLView(BaseView):
+    """
+    A view which provides a base class for views which need to return XHTML
+    It is expected that apps which use this view will be written using Genshi
+    templates.
+    """
+    def __init__(self, req, **kwargs):
+        for key in kwargs:
+          setattr(self, key, kwargs[key])
+        
+    def render(self, req):
+        ctx = genshi.template.Context()
+        self.populate(req, ctx)
+        self.populate_headings(req, ctx)
+        
+        ctx['app_styles'] = req.styles
+        ctx['scripts'] = req.scripts
+        ctx['scripts_init'] = req.scripts_init
+        app_template = os.path.join(os.path.dirname(
+                        inspect.getmodule(self).__file__), self.app_template) 
+        req.write_html_head_foot = False
+        loader = genshi.template.TemplateLoader(".", auto_reload=True)
+        tmpl = loader.load(app_template)
+        app = tmpl.generate(ctx)
+        ctx['app_template'] = app
+        tmpl = loader.load(os.path.join(os.path.dirname(__file__), 
+                                                        'ivle-headings.html'))
+        req.write(tmpl.generate(ctx).render('xhtml', doctype='xhtml'))
+
+    def populate_headings(self, req, ctx):
+        ctx['favicon'] = None
+        ctx['root_dir'] = ivle.conf.root_dir
+        ctx['public_host'] = ivle.conf.public_host
+        if req.user:
+            ctx['login'] = req.user.login
+            ctx['logged_in'] = True
+            ctx['nick'] = req.user.nick
+        else:
+            ctx['login'] = None
+        ctx['publicmode'] = req.publicmode
+        ctx['apps_in_tabs'] = []
+        for urlname in ivle.conf.apps.apps_in_tabs:
+            new_app = {}
+            app = ivle.conf.apps.app_url[urlname]
+            new_app['this_app'] = urlname == self.appname
+            if app.icon:
+                new_app['has_icon'] = True
+                icon_dir = ivle.conf.apps.app_icon_dir
+                icon_url = ivle.util.make_path(os.path.join(icon_dir, app.icon))
+                new_app['icon_url'] = icon_url
+                if new_app['this_app']:
+                    ctx['favicon'] = icon_url
+            else:
+                new_app['has_icon'] = False
+            new_app['path'] = ivle.util.make_path(urlname)
+            new_app['desc'] = app.desc
+            new_app['name'] = app.name
+            ctx['apps_in_tabs'].append(new_app)

